==> client-sdk-react-1.13.0.tgz: package/src/components/Chat/models.ts <==
import React from 'react'
import { ChatAttachmentModel, ChatMessageModel, ParticipantModel, ZocksChatActions } from '../../store'

export interface ChatProps {
  chatActions: ZocksChatActions
  dismiss?: () => void
  chatMessageElement?: React.FC<ChatMessageElementProps>
  chatInputElement?: React.FC<ChatInputElementProps>
}

export interface ChatMessageElementProps {
  chatMessage: ChatMessageModel
  getAttachmentLocation?: (fileId: string) => Promise<string | undefined>
  chatMessageAttachmentElement?: React.FC<ChatMessageAttachmentElementProps>
}

export interface ChatMessageAttachmentElementProps {
  attachment: ChatAttachmentModel
  getAttachmentLocation: (fileId: string) => Promise<string | undefined>
}

export interface ChatInputElementProps {
  messageRecipient: string
  remoteParticipants?: ParticipantModel[]
  onRecipientSelected?: (recipientId: string) => void
  sendPublicMessage?: (message: string, attachment?: ChatAttachmentModel) => void
  sendPrivateMessage?: (message: string, remoteParticipant: ParticipantModel, attachment?: ChatAttachmentModel) => void
  uploadAttachment?: (file: File, remoteParticipant?: ParticipantModel) => Promise<string | undefined>
}

export interface CustomizableChatInputProps {
  chatMessageInputElement?: React.FC<ChatMessageInputElementProps>
  sendButtonElement?: React.FC<SendButtonElementProps>
  recipientSelectorElement?: React.FC<RecipientSelectorElementProps>
  emojiSelectorElement?: React.FC<EmojiSelectorElementProps>
  attachmentUploaderElement?: React.FC<AttachmentUploaderElementProps>
  attachmentDisplayElement?: React.FC<AttachmentDisplayElementProps>
}

export interface ChatMessageInputElementProps extends React.ComponentPropsWithoutRef<any> {
  currentChatMessage: string
  onChatMessageChanged: (message: string) => void
  placeholderText?: string
  sendMessage?: () => void
}

export interface SendButtonElementProps {
  disabled?: boolean
  onClick?: () => void
  buttonText?: string
}

export interface RecipientSelectorElementProps {
  remoteParticipants?: ParticipantModel[]
  onRecipientSelected: (recipientId: string) => void
  selectInfoText?: string
  allParticipantsLabel?: string
}

export interface EmojiSelectorElementProps {
  onSelectEmoji: (emoji: string) => void
  emojis?: string[]
  openButtonElement?: React.FC<EmojiSelectorOpenButtonElementProps>
  currentMessage?: string
}

export interface EmojiSelectorOpenButtonElementProps extends React.ComponentPropsWithoutRef<any> {
  onClick: () => void
}

export interface AttachmentUploaderElementProps {
  uploadAttachment: (file: File, remoteParticipant?: ParticipantModel) => Promise<string | undefined>
  attachmentRecipient?: ParticipantModel
  onAttachmentUploadStarted?: (file: File) => void
  onAttachmentUploadFinished?: (file: File, fileId: string) => void
  onAttachmentUploadFailed?: (file: File) => void
  uploadAttachmentButtonElement?: React.FC<UploadAttachmentButtonElementProps>
}

export interface UploadAttachmentButtonElementProps {
  onClick: () => void
  disabled?: boolean
  hasError?: boolean
}

export interface AttachmentDisplayElementProps {
  attachment?: ChatAttachmentModel
  hasAttachmentError?: boolean
  onClearAttachment?: () => void
  clearAttachmentButtonElement?: React.FC<ClearAttachmentButtonElementProps>
}

export interface ClearAttachmentButtonElementProps {
  onClick: () => void
}

==> client-sdk-react-1.16.0.tgz: package/src/components/Chat/models.ts <==
import React from 'react'
import { ChatAttachmentModel, ChatMessageModel, ParticipantModel, ZocksChatActions } from '../../store'
import { StyledComponent } from '../common'

export interface ChatProps extends StyledComponent {
  chatActions: ZocksChatActions
  dismiss?: () => void
  chatMessageElement?: React.FC<ChatMessageElementProps>
  chatInputElement?: React.FC<ChatInputElementProps>
}

export interface ChatMessageElementProps extends StyledComponent {
  chatMessage: ChatMessageModel
  getAttachmentLocation?: (fileId: string) => Promise<string | undefined>
  chatMessageAttachmentElement?: React.FC<ChatMessageAttachmentElementProps>
}

export interface ChatMessageAttachmentElementProps extends StyledComponent {
  attachment: ChatAttachmentModel
  getAttachmentLocation: (fileId: string) => Promise<string | undefined>
}

export interface ChatInputElementProps extends StyledComponent {
  messageRecipient: string
  remoteParticipants?: ParticipantModel[]
  onRecipientSelected?: (recipientId: string) => void
  sendPublicMessage?: (message: string, attachment?: ChatAttachmentModel) => void
  sendPrivateMessage?: (message: string, remoteParticipant: ParticipantModel, attachment?: ChatAttachmentModel) => void
  uploadAttachment?: (file: File, remoteParticipant?: ParticipantModel) => Promise<string | undefined>
}

export interface CustomizableChatInputProps {
  chatMessageInputElement?: React.FC<ChatMessageInputElementProps>
  sendButtonElement?: React.FC<SendButtonElementProps>
  recipientSelectorElement?: React.FC<RecipientSelectorElementProps>
  emojiSelectorElement?: React.FC<EmojiSelectorElementProps>
  attachmentUploaderElement?: React.FC<AttachmentUploaderElementProps>
  attachmentDisplayElement?: React.FC<AttachmentDisplayElementProps>
}

export interface ChatMessageInputElementProps extends React.ComponentPropsWithoutRef<any>, StyledComponent {
  currentChatMessage: string
  onChatMessageChanged: (message: string) => void
  placeholderText?: string
  sendMessage?: () => void
}

export interface SendButtonElementProps extends StyledComponent {
  disabled?: boolean
  onClick?: () => void
  buttonText?: string
}

export interface RecipientSelectorElementProps extends StyledComponent {
  remoteParticipants?: ParticipantModel[]
  onRecipientSelected: (recipientId: string) => void
  selectInfoText?: string
  allParticipantsLabel?: string
}

export interface EmojiSelectorElementProps extends StyledComponent {
  onSelectEmoji: (emoji: string) => void
  emojis?: string[]
  openButtonElement?: React.FC<EmojiSelectorOpenButtonElementProps>
  currentMessage?: string
}

export interface EmojiSelectorOpenButtonElementProps extends React.ComponentPropsWithoutRef<any>, StyledComponent {
  onClick: () => void
}

export interface AttachmentUploaderElementProps extends StyledComponent {
  uploadAttachment: (file: File, remoteParticipant?: ParticipantModel) => Promise<string | undefined>
  attachmentRecipient?: ParticipantModel
  onAttachmentUploadStarted?: (file: File) => void
  onAttachmentUploadFinished?: (file: File, fileId: string) => void
  onAttachmentUploadFailed?: (file: File) => void
  uploadAttachmentButtonElement?: React.FC<UploadAttachmentButtonElementProps>
}

export interface UploadAttachmentButtonElementProps extends StyledComponent {
  onClick: () => void
  disabled?: boolean
  hasError?: boolean
}

export interface AttachmentDisplayElementProps extends StyledComponent {
  attachment?: ChatAttachmentModel
  hasAttachmentError?: boolean
  onClearAttachment?: () => void
  clearAttachmentButtonElement?: React.FC<ClearAttachmentButtonElementProps>
}

export interface ClearAttachmentButtonElementProps extends StyledComponent {
  onClick: () => void
}
